@@ -60,19 +60,26 @@ def get_status():
     """Get a unified Git and DVC status."""
 
     def print_sep(name: str):
-        print(f"------------ {name} ------------")
+        width = 66
+        txt_width = len(name) + 2
+        buffer_width = (width - txt_width) // 2
+        buffer = "-" * buffer_width
+        typer.echo(f"{buffer} {name} {buffer}")
 
-    print_sep("Code")
-    if os.name == "nt":
-        subprocess.call(["git", "status"])
-        print()
-        print_sep("data")
-        subprocess.call(["dvc", "status"])
-    else:
-        pty.spawn(["git", "status"], lambda fd: os.read(fd, 1024))
-        print()
-        print_sep("Data")
-        pty.spawn(["dvc", "status"], lambda fd: os.read(fd, 1024))
+    def run_cmd(cmd: list[str]):
+        if os.name == "nt":
+            subprocess.call(cmd)
+        else:
+            pty.spawn(cmd, lambda fd: os.read(fd, 1024))
+
+    print_sep("Code (Git)")
+    run_cmd(["git", "status"])
+    typer.echo()
+    print_sep("Data (DVC)")
+    run_cmd(["dvc", "data", "status"])
+    typer.echo()
+    print_sep("Pipeline (DVC)")
+    run_cmd(["dvc", "status"])
 
 
 @app.command(name="add")
@@ -105,6 +112,22 @@ def commit(
     raise NotImplementedError
 
 
+@app.command(name="pull", help="Pull with both Git and DVC.")
+def pull():
+    typer.echo("Git pulling")
+    subprocess.call(["git", "pull"])
+    typer.echo("DVC pulling")
+    subprocess.call(["dvc", "pull"])
+
+
+@app.command(name="push", help="Push with both Git and DVC.")
+def push():
+    typer.echo("Pushing to Git remote")
+    subprocess.call(["git", "push"])
+    typer.echo("Pushing to DVC remote")
+    subprocess.call(["dvc", "push"])
+
+
 @new_app.command(name="figure")
 def new_figure(
     path: str,
@@ -160,7 +183,7 @@ def new_question(
         repo.git.commit(["-m", "Add question"])
 
 
-@app.command(name="server")
+@app.command(name="server", help="Run the local server.")
 def run_server():
     import uvicorn
 
@@ -173,5 +196,72 @@ def run_server():
     )
 
 
+@app.command(
+    name="run",
+    add_help_option=False,
+    help="Run DVC pipeline (a wrapper for `dvc repro`).",
+)
+def run_dvc_repro(
+    targets: Optional[list[str]] = typer.Argument(default=None),
+    help: Annotated[bool, typer.Option("-h", "--help")] = False,
+    quiet: Annotated[bool, typer.Option("-q", "--quiet")] = False,
+    verbose: Annotated[bool, typer.Option("-v", "--verbose")] = False,
+    force: Annotated[bool, typer.Option("-f", "--force")] = False,
+    interactive: Annotated[bool, typer.Option("-i", "--interactive")] = False,
+    single_item: Annotated[bool, typer.Option("-s", "--single-item")] = False,
+    pipeline: Annotated[
+        Optional[str], typer.Option("-p", "--pipeline")
+    ] = None,
+    all_pipelines: Annotated[
+        bool, typer.Option("-P", "--all-pipelines")
+    ] = False,
+    recursive: Annotated[bool, typer.Option("-R", "--recursive")] = False,
+    downstream: Annotated[
+        Optional[list[str]], typer.Option("--downstream")
+    ] = None,
+    force_downstream: Annotated[
+        bool, typer.Option("--force-downstream")
+    ] = False,
+    pull: Annotated[bool, typer.Option("--pull")] = False,
+    allow_missing: Annotated[bool, typer.Option("--allow-missing")] = False,
+    dry: Annotated[bool, typer.Option("--dry")] = False,
+    keep_going: Annotated[bool, typer.Option("--keep-going", "-k")] = False,
+    ignore_errors: Annotated[bool, typer.Option("--ignore-errors")] = False,
+    glob: Annotated[bool, typer.Option("--glob")] = False,
+    no_commit: Annotated[bool, typer.Option("--no-commit")] = False,
+    no_run_cache: Annotated[bool, typer.Option("--no-run-cache")] = False,
+):
+    """A simple wrapper for ``dvc repro``."""
+    if targets is None:
+        targets = []
+    args = targets
+    # Extract any boolean args
+    for name in [
+        "help",
+        "quiet",
+        "verbose",
+        "force",
+        "interactive",
+        "single-item",
+        "all-pipelines",
+        "recursive",
+        "pull",
+        "allow-missing",
+        "dry",
+        "keep-going",
+        "force-downstream",
+        "glob",
+        "no-commit",
+        "no-run-cache",
+    ]:
+        if locals()[name.replace("-", "_")]:
+            args.append("--" + name)
+    if pipeline is not None:
+        args += ["--pipeline", pipeline]
+    if downstream is not None:
+        args += downstream
+    subprocess.call(["dvc", "repro"] + args)
+
+
 def run() -> None:
     app()
